cd
wget http://download.netsurf-browser.org/libs/releases/buildsystem-1.10.tar.gz
tar -xf buildsystem-1.10.tar.gz
make -C buildsystem-1.10 install PREFIX=/opt/elinks

